@@ -72,7 +72,7 @@ def processLine(line: str):
             "transport": {
                 "playstate": playState[int(token[1])],
                 "position_seconds": token[2],
-                "repeat": bool(token[3]),
+                "repeat": bool(int(token[3])),
                 "position_string": token[4],
                 "position_string_beats": token[5],
             },
@@ -106,7 +106,7 @@ def processLine(line: str):
             "sendcnt": token[10],
             "recvcnt": token[11],
             "hwoutcnt": token[12],
-            "color": token[13],
+            "color": "#000000" if int(token[13]) == 0 else f"#{hex(int(token[13]))[3:]}",
         })
         return False
 
